/// <reference types="passport" />
import { Strategy } from 'passport-strategy';
import * as passport from 'passport';
import { AuthenticationSuccess, ExegesisPluginContext, Authenticator, AuthenticatorInfo } from 'exegesis';
export declare type PassportToExegesisResult = (Pick<AuthenticationSuccess, 'user' | 'roles' | 'scopes'>) & {
    [prop: string]: any;
};
export interface PassportUserToExegesisUserFn {
    (user: any, pluginContext: ExegesisPluginContext): PassportToExegesisResult;
}
export interface IsPresentFn {
    (pluginContext: ExegesisPluginContext, info: AuthenticatorInfo): boolean;
}
export interface Options {
    convert?: PassportUserToExegesisUserFn;
    isPresent?: IsPresentFn;
    passportOptions?: any;
}
/**
 * Create a new Exegesis authenticator from a passport instance.
 *
 * @param passport - The passport instance to call into.  This should be installed
 *   in your middleware chain before exegesis with `app.use(passport.initialize())`.
 * @param strategyName - The name of the passport strategy to use.  This strategy
 *   should be registered with passport with `passport.use(...)`.
 * @param options.converter - A function to convert Passport users into
 *   `{user, roles, scopes}` objects.  If not defined, `user.roles` will be used
 *   as roles, and `user.scopes` will be used as scopes.
 * @param options.isPresent - A function to check if the authentication
 *   scheme was attempted or not.
 * @param options.passportOptions - Options to pass to the passport strategy.
 * @returns - An Exegesis authenticator.
 */
export declare function exegesisPassport(passport: passport.Authenticator, strategyName: string, options?: Options): Authenticator;
/**
 * Create a new Exegesis authenticator from a passport strategy.
 *
 * @param strategy - An instance of a Passport strategy to call.  Passport
 *   does not need to be registered as a middleware for this to work.
 * @param options.converter - A function to convert Passport users into
 *   `{user, roles, scopes}` objects.  If not defined, `user.roles` will be used
 *   as roles, and `user.scopes` will be used as scopes.
 * @param options.isPresent - A function to check if the authentication
 *   scheme was attempted or not.
 * @param options.passportOptions - Options to pass to the passport strategy.
 * @returns - An Exegesis authenticator.
 */
export declare function exegesisPassport(strategy: Strategy, options?: Options): Authenticator;
export default exegesisPassport;
